<?php

namespace Albis\AlbisLease\Controller\Api;

use GuzzleHttp\Client;
use Shopware\Core\Framework\Routing\RouteScope;
use Shopware\Core\Framework\Validation\DataBag\RequestDataBag;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\Routing\Annotation\Route;

/**
 * @Route(defaults={"_routeScope"={"api"}})
 */
class ApiTestController
{
    /**
     * @Route(path="/api/_action/albis-api/verify")
     */
    public function check(RequestDataBag $dataBag): JsonResponse
    {
        $endpoint = $dataBag->get('AlbisLease.config.endpoint');
        $username = $dataBag->get('AlbisLease.config.username');
        $password = $dataBag->get('AlbisLease.config.password');

        if(!$endpoint || !$username || !$password) {
            return new JsonResponse([
                'success' => false,
            ]);
        }
        
        $client = new Client();

        $response = $client->post($endpoint, [
            'json' => [
                'id' => sha1(microtime()),
                'method' => 'ping',
                'params' => [
                    $username,
                    $password,
                ]
            ]
        ]);

        $response = json_decode($response->getBody()->getContents(), true);

        if($response['result'] == 'pong') {
            return new JsonResponse([
                'success' => true,
            ]);
        }
        
        return new JsonResponse([
            'success' => false,
            'code' => $response['error']['code'],
            'message' => $response['error']['message']
        ]);
    }
}
