<?php declare(strict_types=1);

namespace Albis\AlbisLease\Migration;

use Doctrine\DBAL\Connection;
use Doctrine\DBAL\Exception\UniqueConstraintViolationException;
use Shopware\Core\Defaults;
use Shopware\Core\Framework\Migration\MigrationStep;
use Shopware\Core\Framework\Uuid\Uuid;

class Migration1552484873Custom extends MigrationStep
{
    public function getCreationTimestamp(): int
    {
        return 1552484873;
    }

    public function update(Connection $connection): void
    {
        $this->addGroup($connection, 1, 'EDV (Hard- und Software)', 18, 30, 1);
        $this->addGroup($connection, 2, 'Software', 18, 30, 2);
        $this->addGroup($connection, 3, 'Kopierer', 36, 75, 3);
        $this->addGroup($connection, 4, 'Foto-, Film-, Videogeräte, Beamer, TV', 36, 75, 4);
        $this->addGroup($connection, 5, 'Frankiermaschinen', 42, 86, 16);
        $this->addGroup($connection, 6, 'Telefonanlagen', 42, 86, 6);
        $this->addGroup($connection, 7, 'EC-Karten-Terminals', 42, 86, 28);
        $this->addGroup($connection, 8, 'Kassensysteme', 30, 64, 7);
        $this->addGroup($connection, 9, 'Medizintechnik', 36, 66, 8);
        $this->addGroup($connection, 10, 'Maschinen (Holzbe- und -verarbeitung)', 36, 60, 18);
        $this->addGroup($connection, 11, 'Maschinen (Metallbe- und -verarbeitung)', 36, 60, 17);
        $this->addGroup($connection, 12, 'Maschinen (sonstige)', 36, 60, 19);
        $this->addGroup($connection, 13, 'Werkstattausrüstung', 42, 60, 9);
        $this->addGroup($connection, 14, 'Kaffee-/Versorgungsautomaten', 36, 72, 14);
        $this->addGroup($connection, 15, 'Bäckereimaschinen', 36, 60, 21);
        $this->addGroup($connection, 16, 'Flurfördertechnik', 39, 86, 26);
        $this->addGroup($connection, 17, 'Textilreinigungsgeräte', 48, 96, 25);
        $this->addGroup($connection, 18, 'Digitalkameras', 24, 48, 5);
        $this->addGroup($connection, 19, 'Telematik-/Satellitenortungssystem', 24, 43, 27);
        $this->addGroup($connection, 20, 'Fleischereimaschinen, Metzgereibedarf', 36, 60, 22);
        $this->addGroup($connection, 21, 'Elektrowerkzeuge', 21, 42, 23);
        $this->addGroup($connection, 22, 'Sicherheitstechnik', 36, 72, 15);
        $this->addGroup($connection, 23, 'Großküchentechnik', 30, 60, 10);
        $this->addGroup($connection, 24, 'div. Handwerksmaschinen  ', 36, 60, 20);
        $this->addGroup($connection, 25, 'Sport- und Fitnessgeräte', 24, 54, 24);
        $this->addGroup($connection, 26, 'Forst-, Park- und Gartengeräte ohne Strassenzulassung', 30, 60, 11);
        $this->addGroup($connection, 27, 'Motorsägen', 18, 24, 13);
        $this->addGroup($connection, 28, 'Forst-, Park- und Gartengeräte mit Strassenzulassung', 30, 60, 12);
        $this->addGroup($connection, 29, 'Büromöbel', 63, 140, 29);
        $this->addGroup($connection, 30, 'Kuvertiermaschinen', 42, 86, 16);
        $this->addGroup($connection, 31, 'Fahrzeugeinrichtungen', 36, 48, 31);
        $this->addGroup($connection, 32, 'Fahrrad/E-Bike', 36, 75, 32);
        $this->addGroup($connection, 33, 'LED-Technik', 24, 54, 33);
        $this->addGroup($connection, 34, 'Messtechnik', 39, 84, 34);
        $this->addGroup($connection, 34, 'Kaffee-/Versorgungsmaschinen', 24, 54, 15);
        $this->addGroup($connection, 36, 'GPS-Systeme', 39, 84, 36);
        $this->addGroup($connection, 37, 'Sonstiges', 18, 66, 99);
    }

    public function updateDestructive(Connection $connection): void
    {
    }

    private function addGroup(Connection $connection, $albisId, $description, $runtimeMin, $runtimeMax, $position)
    {
        try {
            $connection->executeUpdate(
                'INSERT INTO `albis_product_group` (`id`, `albis_id`, `description`, `runtime_min`, `runtime_max`, `position`, `created_at`, `updated_at`)
             VALUES (:id, :albis_id, :description, :runtime_min, :runtime_max, :position, :created_at, :updated_at)',
                [
                    'id' => Uuid::randomBytes(),
                    'albis_id' => $albisId,
                    'description' => $description,
                    'runtime_min' => $runtimeMin,
                    'runtime_max' => $runtimeMax,
                    'position' => $position,
                    'created_at' => (new \DateTime())->format(Defaults::STORAGE_DATE_TIME_FORMAT),
                    'updated_at' => (new \DateTime())->format(Defaults::STORAGE_DATE_TIME_FORMAT),
                ]
            );
        } catch (UniqueConstraintViolationException $e) {
            // don't add alibs groups if they already exist
            return;
        }
    }
}